Description Usage Value Author(s) See Also
Checks if the file specification is a file.
1 2 |
Returns TRUE if the file specification is a file, otherwise
FALSE is returned.
Henrik Bengtsson (http://www.braju.com/R/)
To check if it is a directory see *isDirectory().
Internally file.info() is used.
For more information see File.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.